@@ -2,7 +2,27 @@
 #'
 #' Create an object which can be used to send messages to an SMTP server.
 #'
-#' These functions return a function which can then be called with a message object.
+#' These functions return a function that can then be called with a message
+#' object. This function mediates the interaction with the Simple Mail Transfer
+#' Protocol (SMTP) server.
+#'
+#' SMTP is a plain text protocol, which means that it is not secure. The secure
+#' variant, SMTPS, comes in two flavours: TLS and StartTLS. With TLS (also
+#' called Implicit TLS) the connection with the server is initiated using an
+#' Secure Socket Layer (SSL) or Transport Layer Security (TLS) certificate. Such
+#' a connection is secure from the start. By contract, a StartTLS connection is
+#' initiated in plain text and then upgraded to TLS if possible. By convention
+#' TLS operates on port 465 and StartTLS on port 587.
+#'
+#' The specifications of an SMTP server are given in an SMTP URL, which takes one
+#' of the following forms:
+#'
+#' - `mail.example.com` — hostname only
+#' - `mail.example.com:587` — hostname and port
+#' - `smtp://mail.example.com` — SMTP URL (default port)
+#' - `smtps://mail.example.com` — SMTPS URL (default port)
+#' - `smtp://mail.example.com:25` — SMTP URL (explicit port)
+#' - `smtps://mail.example.com:587` — SMTPS URL (explicit port)
 #'
 #' @name server
 #'
@@ -14,10 +34,14 @@
 #' @param reuse Whether the connection to the SMTP server should be left open for reuse.
 #' @param helo The HELO domain name of the sending host. If left as \code{NA} then will use local host name.
 #' @param protocol Which protocol (SMTP or SMTPS) to use for communicating with
-#'   the server. Default will choose appropriate protocol based on port.
+#'  the server. Default will choose appropriate protocol based on port.
+#' @param use_ssl Whether to use SSL. If not specified then SSL will be used if the port is 465 or 587.
+#'  This enables SSL on non-standard ports.
 #' @param test Test login to server.
 #' @param max_times Maximum number of times to retry.
 #' @param pause_base Base delay (in seconds) for exponential backoff. See \link[purrr]{rate_backoff}.
+#' @param sandbox Use email sandbox to test server.
+#' @param bulk Send bulk mail to multiple recipients.
 #' @param ... Additional curl options. See \code{curl::curl_options()} for a list of supported options.
 #'
 #' @return A function which is used to send messages to the server.
@@ -70,6 +94,7 @@ server <- function(host,
                    reuse = TRUE,
                    helo = NA,
                    protocol = NA,
+                   use_ssl = NA,
                    test = FALSE,
                    pause_base = 1,
                    max_times = 5,
@@ -95,10 +120,20 @@ server <- function(host,
   }
 
   port <- as.integer(port)
-  if (port %in% c(465, 587)) {
-    use_ssl <- 1
+  if (is.na(use_ssl)) {
+    if (port %in% c(465, 587)) {
+      use_ssl <- 1
+    } else {
+      use_ssl <- 0
+    }
   } else {
-    use_ssl <- 0
+    # If use_ssl can be interpreted as Boolean then set accordingly.
+    use_ssl <- ifelse(use_ssl, 1, 0)
+    # If not then set use_ssl to false.
+    #
+    # NOTE: Need to check for NA again here because NA can come from previous ifelse().
+    #
+    use_ssl <- ifelse(is.na(use_ssl), 0, use_ssl)
   }
 
   # Create an insistent version of send_mail().
@@ -214,7 +249,7 @@ gmail <- function(username,
 #'
 #' @section Sendgrid:
 #'
-#' To use SendGrid you'll need to first \href{https://docs.sendgrid.com/for-developers/sending-email/integrating-with-the-smtp-api}{create an API key}. # nolint
+#' To use SendGrid you'll need to first \href{https://www.twilio.com/docs/sendgrid/for-developers/sending-email/integrating-with-the-smtp-api}{create an API key}. # nolint
 #' Then use the API key as the password.
 #'
 #' SendGrid will accept messages on ports 25, 587 and 2525 (using SMTP) as well
@@ -348,9 +383,7 @@ mailersend <- function(username,
 #'   username = "bob",
 #'   password = "F!Uosd6xbhSjd%63"
 #' )
-mailfence <- function(username,
-                      password,
-                      ...) {
+mailfence <- function(username, password, ...) {
   fcall <- match.call(expand.dots = TRUE) # nocov start
 
   fcall[[1]] <- server
@@ -364,8 +397,11 @@ mailfence <- function(username,
 #'
 #' @section ZeptoMail:
 #'
-#' SMTP Bucket is a fake SMTP server that captures all the messages it receives
-#' and makes them available through a website or REST API.
+#' Zeptomail is an email sending service provided by Zoho Corporation. It is
+#' designed primarily for transactional email delivery, which includes emails
+#' like password resets, order confirmations, notifications, and other
+#' automated, non-marketing communications that websites and applications need
+#' to send to their users.
 #'
 #' @export
 #'
@@ -375,8 +411,7 @@ mailfence <- function(username,
 #' # nolint start
 #' smtp <- zeptomail("yA6KbHsL4l2mmI8Ns0/fs9iSTj8yG0dYBgfIG0j6Fsv4P2uV32xh8ciEYNYlRkgCC7wRfkgWA==")
 #' # nolint end
-zeptomail <- function(password,
-                      ...) {
+zeptomail <- function(password, ...) {
   fcall <- match.call(expand.dots = TRUE) # nocov start
 
   fcall[[1]] <- server
@@ -410,3 +445,33 @@ smtpbucket <- function(...) {
 
   eval(fcall, parent.frame())
 }
+
+#' @rdname server
+#'
+#' @section SMTP Bucket:
+#'
+#' SMTP Bucket is a fake SMTP server that captures all the messages it receives
+#' and makes them available through a website or REST API.
+#'
+#' @export
+#'
+#' @examples
+#'
+#' # SMTP Bucket server.
+#' smtp <- smtpbucket()
+mailtrap <- function(username, password, sandbox = FALSE, bulk = FALSE, ...) {
+  fcall <- match.call(expand.dots = TRUE)
+
+  fcall[[1]] <- server
+  fcall$port <- 587
+
+  if (sandbox) {
+    fcall$host <- "sandbox.smtp.mailtrap.io"
+  } else if (bulk) {
+    fcall$host <- "bulk.smtp.mailtrap.io"
+  } else {
+    fcall$host <- "live.smtp.mailtrap.io"
+  }
+
+  eval(fcall, parent.frame())
+}
